pub struct AuthSession { /* private fields */ }Expand description
Response structure for SiServer LDAP authentication.
The first stage of authentication returns a temporary token that must be exchanged for a session cookie in the second stage.