pub struct JiraInboxConfig {
pub enabled: bool,
pub poll_interval_secs: u64,
pub notify: bool,
pub custom_fields: Vec<JiraCustomField>,
pub sort_by_field: Option<String>,
}Expand description
Settings for polling assigned open Jira issues into the local inbox.
Fields
enabled: boolWhether the watcher should poll Jira for open assigned issues.
poll_interval_secs: u64Seconds between Jira inbox polls (default 300 = 5 minutes).
notify: boolWhether to show a desktop toast when a new issue appears.
custom_fields: Vec<JiraCustomField>Extra Jira fields to fetch (custom fields such as Scoring).
sort_by_field: Option<String>Field id used for ranking (DESC), typically Scoring (customfield_โฆ).
Implementations
Sourceimpl JiraInboxConfig
impl JiraInboxConfig
Sourcepub fn extra_field_ids(&self) -> Vec<String>
pub fn extra_field_ids(&self) -> Vec<String>
Field ids to request from Jira search (custom fields only).